NautilusTrader adapter for the Hyperliquid decentralized exchange.
The nautilus-hyperliquid crate provides integration with the Hyperliquid API for
trading perpetual futures on a decentralized exchange.
NautilusTrader
NautilusTrader is an open-source, production-grade, Rust-native engine for multi-asset, multi-venue trading systems.
The system spans research, deterministic simulation, and live execution within a single event-driven architecture, providing research-to-live semantic parity.
Feature Flags
This crate provides feature flags to control source code inclusion during compilation, depending on the intended use case, i.e. whether to provide Python bindings for the nautilus_trader Python package, or as part of a Rust only build.
arrow: Enables Apache Arrow data support.examples: Enables the crate’s example binaries.extension-module: Builds as a Python extension module.high-precision(default): Enables high-precision mode to use 128-bit value types.python: Enables Python bindings from PyO3.
Re-exports
pub use crate::config::HyperliquidDataClientConfig;pub use crate::config::HyperliquidExecutionClientConfig;pub use crate::data::HyperliquidDataClient;pub use crate::execution::HyperliquidExecutionClient;pub use crate::factories::HyperliquidDataClientFactory;pub use crate::factories::HyperliquidExecutionClientFactory;pub use crate::http::client::HyperliquidHttpClient;pub use crate::websocket::client::HyperliquidWebSocketClient;
Modules
- account
- Account-address resolution for Hyperliquid execution queries and subscriptions.
- common
- config
- Configuration structures for the Hyperliquid adapter.
- data
- data_
types - Hyperliquid-specific custom data types.
- execution
- Live execution client implementation for the Hyperliquid adapter.
- factories
- Factory functions for creating Hyperliquid clients and components.
- http
- outcome_
settlement - Runtime dispatch for HIP-4 outcome settlements.
- signing
- Hyperliquid EIP-712 signing and nonce management.
- websocket