pub enum HyperliquidRejectCode {
Show 18 variants
Tick,
MinTradeNtl,
MinTradeSpotNtl,
PerpMargin,
ReduceOnly,
BadAloPx,
IocCancel,
BadTriggerPx,
MarketOrderNoLiquidity,
PositionIncreaseAtOpenInterestCap,
PositionFlipAtOpenInterestCap,
TooAggressiveAtOpenInterestCap,
OpenInterestIncrease,
InsufficientSpotBalance,
Oracle,
PerpMaxPosition,
MissingOrder,
Unknown(String),
}Variants
Tick
Price must be divisible by tick size.
MinTradeNtl
Order must have minimum value of $10.
MinTradeSpotNtl
Order must have minimum value of 10 {quote_token}.
PerpMargin
Insufficient margin to place order.
ReduceOnly
Reduce only order would increase position.
BadAloPx
Post only order would have immediately matched.
IocCancel
Order could not immediately match.
BadTriggerPx
Invalid TP/SL price.
MarketOrderNoLiquidity
No liquidity available for market order.
PositionIncreaseAtOpenInterestCap
Position increase at open interest cap.
PositionFlipAtOpenInterestCap
Position flip at open interest cap.
TooAggressiveAtOpenInterestCap
Too aggressive at open interest cap.
OpenInterestIncrease
Open interest increase.
InsufficientSpotBalance
Insufficient spot balance.
Oracle
Oracle issue.
PerpMaxPosition
Perp max position.
MissingOrder
Missing order.
Unknown(String)
Unknown reject reason with raw error message.
Implementations
Sourceimpl HyperliquidRejectCode
impl HyperliquidRejectCode
Sourcepub fn from_api_error(error_message: &str) -> Self
pub fn from_api_error(error_message: &str) -> Self
Parse reject code from Hyperliquid API error message.
Sourcepub fn from_error_string(error: &str) -> Self
👎Deprecated since 0.50.0: String parsing is fragile; use HyperliquidRejectCode::from_api_error() instead
pub fn from_error_string(error: &str) -> Self
String parsing is fragile; use HyperliquidRejectCode::from_api_error() instead
Parses reject code from error string.
Deprecated: This method uses substring matching which is fragile and not robust.
Use from_api_error() instead, which provides a migration path for structured error handling.