pub enum HyperliquidExecModifyTarget {
Oid(OrderId),
Cloid(Cloid),
}Expand description
Target of a modify request.
Hyperliquid names this field oid, but accepts either a numeric venue
order ID or a CLOID.
Variants
Implementations
Sourceimpl HyperliquidExecModifyTarget
impl HyperliquidExecModifyTarget
Sourcepub fn from_venue_order_id(
venue_order_id: &VenueOrderId,
) -> Result<Self, ParseIntError>
pub fn from_venue_order_id( venue_order_id: &VenueOrderId, ) -> Result<Self, ParseIntError>
Creates a numeric modify target from a Nautilus venue order ID.
Errors
Returns an error if the venue order ID is not a numeric Hyperliquid order ID.