pub struct Cloid(pub [u8; 16]);Expand description
A 128-bit client order ID represented as a hex string with 0x prefix.
Tuple Fields
0: [u8; 16]Implementations
Sourceimpl Cloid
impl Cloid
Sourcepub fn from_hex<S: AsRef<str>>(s: S) -> Result<Self, String>
pub fn from_hex<S: AsRef<str>>(s: S) -> Result<Self, String>
Creates a new Cloid from a hex string.
Errors
Returns an error if the string is not a valid 128-bit hex with 0x prefix.
Sourcepub fn from_client_order_id(client_order_id: ClientOrderId) -> Self
pub fn from_client_order_id(client_order_id: ClientOrderId) -> Self
Creates a deterministic Cloid from a Nautilus ClientOrderId.
Sourcepub fn from_legacy_client_order_id(client_order_id: ClientOrderId) -> Self
pub fn from_legacy_client_order_id(client_order_id: ClientOrderId) -> Self
Creates a legacy deterministic Cloid from a Nautilus ClientOrderId.
Sourcepub fn is_uuid_v4(&self) -> bool
pub fn is_uuid_v4(&self) -> bool
Returns whether the CLOID matches the UUIDv4 version and variant bits.