pub struct HyperliquidExchangeRequest<T> {
pub action: T,
pub nonce: u64,
pub signature: HyperliquidSignature,
pub vault_address: Option<String>,
pub expires_after: Option<u64>,
}Expand description
Represents an exchange action request wrapper for POST /exchange.
Fields
action: TThe action to perform.
nonce: u64Request nonce for replay protection.
signature: HyperliquidSignatureECC signature over the action.
vault_address: Option<String>Optional vault address for sub-account trading.
expires_after: Option<u64>Optional expiration time in milliseconds.
Implementations
Sourceimpl<T> HyperliquidExchangeRequest<T>where
T: Serialize,
impl<T> HyperliquidExchangeRequest<T>where
T: Serialize,
Sourcepub fn new(action: T, nonce: u64, signature: &str) -> Result<Self, String>
pub fn new(action: T, nonce: u64, signature: &str) -> Result<Self, String>
Create a new exchange request with the given action.
Sourcepub fn with_vault(
action: T,
nonce: u64,
signature: &str,
vault_address: String,
) -> Result<Self, String>
pub fn with_vault( action: T, nonce: u64, signature: &str, vault_address: String, ) -> Result<Self, String>
Create a new exchange request with vault address for sub-account trading.
Sourcepub fn to_sign_value(&self) -> Result<Value>
pub fn to_sign_value(&self) -> Result<Value>
Convert to JSON value for signing purposes.