pub struct HyperliquidExecBuilderFee {
pub address: String,
pub fee_tenths_bp: u32,
}Expand description
Builder code for order attribution in the exchange endpoint.
The fee is specified in tenths of a basis point.
For example, f: 10 represents 1 basis point (0.01%).
Fields
address: StringBuilder address for attribution.
fee_tenths_bp: u32Fee in tenths of a basis point.