pub struct HyperliquidExecCancelByCloidRequest {
pub asset: AssetId,
pub cloid: Cloid,
}Expand description
Cancel specification for canceling orders by client order ID via exchange endpoint.
Note: Unlike order placement which uses abbreviated field names (“a”, “c”), cancel-by-cloid uses full field names (“asset”, “cloid”) per the Hyperliquid API.
Fields
asset: AssetIdAsset ID.
cloid: CloidClient order ID to cancel.