pub struct ExchangeAction {
pub action_type: ExchangeActionType,
pub params: ExchangeActionParams,
}Expand description
Represents an exchange action wrapper for POST /exchange.
Fields
action_type: ExchangeActionTypeparams: ExchangeActionParamsImplementations
Sourceimpl ExchangeAction
impl ExchangeAction
Sourcepub fn order(
orders: Vec<HyperliquidExecPlaceOrderRequest>,
builder: Option<HyperliquidExecBuilderFee>,
) -> Self
pub fn order( orders: Vec<HyperliquidExecPlaceOrderRequest>, builder: Option<HyperliquidExecBuilderFee>, ) -> Self
Creates an action to place orders with builder attribution.
Sourcepub fn cancel(cancels: Vec<HyperliquidExecCancelByCloidRequest>) -> Self
pub fn cancel(cancels: Vec<HyperliquidExecCancelByCloidRequest>) -> Self
Creates an action to cancel orders.
Sourcepub fn cancel_by_cloid(
cancels: Vec<HyperliquidExecCancelByCloidRequest>,
) -> Self
pub fn cancel_by_cloid( cancels: Vec<HyperliquidExecCancelByCloidRequest>, ) -> Self
Creates an action to cancel orders by client order ID.
Sourcepub fn modify(request: HyperliquidExecModifyOrderRequest) -> Self
pub fn modify(request: HyperliquidExecModifyOrderRequest) -> Self
Creates an action to modify an order.
Sourcepub fn update_leverage(asset: u32, is_cross: bool, leverage: u32) -> Self
pub fn update_leverage(asset: u32, is_cross: bool, leverage: u32) -> Self
Creates an action to update leverage for an asset.
Sourcepub fn update_isolated_margin(asset: u32, is_buy: bool, ntli: i64) -> Self
pub fn update_isolated_margin(asset: u32, is_buy: bool, ntli: i64) -> Self
Creates an action to update isolated margin for an asset.