pub struct InfoRequest {
pub request_type: HyperliquidInfoRequestType,
pub params: InfoRequestParams,
}Expand description
Represents an info request wrapper for POST /info.
Fields
request_type: HyperliquidInfoRequestTypeparams: InfoRequestParamsImplementations
Sourceimpl InfoRequest
impl InfoRequest
Sourcepub fn all_perp_metas() -> Self
pub fn all_perp_metas() -> Self
Creates a request to get metadata for all perp dexes (standard + HIP-3).
Sourcepub fn meta_and_asset_ctxs() -> Self
pub fn meta_and_asset_ctxs() -> Self
Creates a request to get metadata with asset contexts (for price precision).
Sourcepub fn spot_meta_and_asset_ctxs() -> Self
pub fn spot_meta_and_asset_ctxs() -> Self
Creates a request to get spot metadata with asset contexts.
Sourcepub fn user_fills(user: &str) -> Self
pub fn user_fills(user: &str) -> Self
Creates a request to get user fills.
Sourcepub fn order_status(user: &str, oid: u64) -> Self
pub fn order_status(user: &str, oid: u64) -> Self
Creates a request to get order status for a user.
Sourcepub fn open_orders(user: &str) -> Self
pub fn open_orders(user: &str) -> Self
Creates a request to get all open orders for a user.
Sourcepub fn frontend_open_orders(user: &str) -> Self
pub fn frontend_open_orders(user: &str) -> Self
Creates a request to get frontend open orders (includes more detail).
Sourcepub fn clearinghouse_state(user: &str) -> Self
pub fn clearinghouse_state(user: &str) -> Self
Creates a request to get user state (balances, positions, margin).
Sourcepub fn user_fees(user: &str) -> Self
pub fn user_fees(user: &str) -> Self
Creates a request to get user fee schedule and effective rates.
Sourcepub fn candle_snapshot(
coin: &str,
interval: HyperliquidBarInterval,
start_time: u64,
end_time: u64,
) -> Self
pub fn candle_snapshot( coin: &str, interval: HyperliquidBarInterval, start_time: u64, end_time: u64, ) -> Self
Creates a request to get candle/bar data.