pub enum HyperliquidWsChannel {
Show 22 variants
SubscriptionResponse,
Trades,
L2Book,
Bbo,
Candle,
AllMids,
Notification,
OrderUpdates,
UserEvents,
UserFills,
UserFundings,
UserNonFundingLedgerUpdates,
ActiveAssetCtx,
ActiveSpotAssetCtx,
ActiveAssetData,
UserTwapSliceFills,
UserTwapHistory,
WebData2,
User,
Post,
Pong,
Error,
}Expand description
WebSocket channel names for Hyperliquid.
Variants
SubscriptionResponse
Trades
L2Book
Bbo
Candle
AllMids
Notification
OrderUpdates
UserEvents
UserFills
UserFundings
UserNonFundingLedgerUpdates
ActiveAssetCtx
ActiveSpotAssetCtx
ActiveAssetData
UserTwapSliceFills
UserTwapHistory
WebData2
User
Generic user channel - Hyperliquid sends fills/events on this channel.
Post
Pong
Error
Implementations
Sourceimpl HyperliquidWsChannel
impl HyperliquidWsChannel
Sourcepub fn is_public(&self) -> bool
pub fn is_public(&self) -> bool
Returns true if this is a public channel (does not require authentication).
Sourcepub fn is_private(&self) -> bool
pub fn is_private(&self) -> bool
Returns true if this is a private channel (requires authentication).
Sourcepub fn from_wire_str(s: &str) -> Option<Self>
pub fn from_wire_str(s: &str) -> Option<Self>
Parses a channel from its wire-format string (e.g., “allMids”).