pub enum HandlerCommand {
Show 14 variants
SetClient(WebSocketClient),
Disconnect,
Subscribe {
subscriptions: Vec<SubscriptionRequest>,
},
Unsubscribe {
subscriptions: Vec<SubscriptionRequest>,
},
Post {
id: u64,
request: PostRequest,
},
InitializeInstruments(Vec<InstrumentAny>),
UpdateInstrument(InstrumentAny),
AddBarType {
key: String,
bar_type: BarType,
},
RemoveBarType {
key: String,
},
UpdateAssetContextSubs {
coin: Ustr,
data_types: AHashSet<AssetContextDataType>,
},
UpdateTradeSubs {
coin: Ustr,
uses: TradeStreamUses,
},
CacheAllDexAssetCtxsInstrumentIds(AHashMap<Ustr, Vec<Option<InstrumentId>>>),
CacheSpotFillCoins(AHashMap<Ustr, Ustr>),
SetDepth10Sub {
coin: Ustr,
subscribed: bool,
},
}Expand description
Commands sent from the outer client to the inner message handler.
Variants
SetClient(WebSocketClient)
Set the WebSocketClient for the handler to use.
Disconnect
Disconnect the WebSocket connection.
Subscribe
Subscribe to the given subscriptions.
Fields
subscriptions: Vec<SubscriptionRequest>Unsubscribe
Unsubscribe from the given subscriptions.
Fields
subscriptions: Vec<SubscriptionRequest>Post
Send a WebSocket post request.
InitializeInstruments(Vec<InstrumentAny>)
Initialize the instruments cache with the given instruments.
UpdateInstrument(InstrumentAny)
Update a single instrument in the cache.
AddBarType
Add a bar type mapping for candle parsing.
RemoveBarType
Remove a bar type mapping.
UpdateAssetContextSubs
Update asset context subscriptions for a coin.
UpdateTradeSubs
Update the logical consumers of a trades stream for a coin.
CacheAllDexAssetCtxsInstrumentIds(AHashMap<Ustr, Vec<Option<InstrumentId>>>)
Cache the ordered instrument IDs needed to normalize allDexsAssetCtxs.
CacheSpotFillCoins(AHashMap<Ustr, Ustr>)
Cache spot fill coin mappings for instrument lookup.
SetDepth10Sub
Flag whether the l2Book stream for coin should also be emitted
as NautilusWsMessage::Depth10 snapshots.