pub struct HyperliquidExecClientConfigBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> HyperliquidExecClientConfigBuilder<S>
impl<S: State> HyperliquidExecClientConfigBuilder<S>
Sourcepub fn build(self) -> HyperliquidExecClientConfigwhere
S: IsComplete,
pub fn build(self) -> HyperliquidExecClientConfigwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn private_key(
self,
value: String,
) -> HyperliquidExecClientConfigBuilder<SetPrivateKey<S>>where
S::PrivateKey: IsUnset,
pub fn private_key(
self,
value: String,
) -> HyperliquidExecClientConfigBuilder<SetPrivateKey<S>>where
S::PrivateKey: IsUnset,
Sourcepub fn maybe_private_key(
self,
value: Option<String>,
) -> HyperliquidExecClientConfigBuilder<SetPrivateKey<S>>where
S::PrivateKey: IsUnset,
pub fn maybe_private_key(
self,
value: Option<String>,
) -> HyperliquidExecClientConfigBuilder<SetPrivateKey<S>>where
S::PrivateKey: IsUnset,
Sourcepub fn vault_address(
self,
value: String,
) -> HyperliquidExecClientConfigBuilder<SetVaultAddress<S>>where
S::VaultAddress: IsUnset,
pub fn vault_address(
self,
value: String,
) -> HyperliquidExecClientConfigBuilder<SetVaultAddress<S>>where
S::VaultAddress: IsUnset,
Sourcepub fn maybe_vault_address(
self,
value: Option<String>,
) -> HyperliquidExecClientConfigBuilder<SetVaultAddress<S>>where
S::VaultAddress: IsUnset,
pub fn maybe_vault_address(
self,
value: Option<String>,
) -> HyperliquidExecClientConfigBuilder<SetVaultAddress<S>>where
S::VaultAddress: IsUnset,
Sourcepub fn account_address(
self,
value: String,
) -> HyperliquidExecClientConfigBuilder<SetAccountAddress<S>>where
S::AccountAddress: IsUnset,
pub fn account_address(
self,
value: String,
) -> HyperliquidExecClientConfigBuilder<SetAccountAddress<S>>where
S::AccountAddress: IsUnset,
Optional (Some / Option setters). Optional main account address when using an agent wallet (API sub-key). When set, used for balance queries, position reports, and WS subscriptions instead of the address derived from the private key.
If not provided and no explicit vault address is set, falls back to
the HYPERLIQUID_ACCOUNT_ADDRESS environment variable.
Sourcepub fn maybe_account_address(
self,
value: Option<String>,
) -> HyperliquidExecClientConfigBuilder<SetAccountAddress<S>>where
S::AccountAddress: IsUnset,
pub fn maybe_account_address(
self,
value: Option<String>,
) -> HyperliquidExecClientConfigBuilder<SetAccountAddress<S>>where
S::AccountAddress: IsUnset,
Optional (Some / Option setters). Optional main account address when using an agent wallet (API sub-key). When set, used for balance queries, position reports, and WS subscriptions instead of the address derived from the private key.
If not provided and no explicit vault address is set, falls back to
the HYPERLIQUID_ACCOUNT_ADDRESS environment variable.
Sourcepub fn base_url_ws(
self,
value: String,
) -> HyperliquidExecClientConfigBuilder<SetBaseUrlWs<S>>where
S::BaseUrlWs: IsUnset,
pub fn base_url_ws(
self,
value: String,
) -> HyperliquidExecClientConfigBuilder<SetBaseUrlWs<S>>where
S::BaseUrlWs: IsUnset,
Sourcepub fn maybe_base_url_ws(
self,
value: Option<String>,
) -> HyperliquidExecClientConfigBuilder<SetBaseUrlWs<S>>where
S::BaseUrlWs: IsUnset,
pub fn maybe_base_url_ws(
self,
value: Option<String>,
) -> HyperliquidExecClientConfigBuilder<SetBaseUrlWs<S>>where
S::BaseUrlWs: IsUnset,
Sourcepub fn base_url_http(
self,
value: String,
) -> HyperliquidExecClientConfigBuilder<SetBaseUrlHttp<S>>where
S::BaseUrlHttp: IsUnset,
pub fn base_url_http(
self,
value: String,
) -> HyperliquidExecClientConfigBuilder<SetBaseUrlHttp<S>>where
S::BaseUrlHttp: IsUnset,
Sourcepub fn maybe_base_url_http(
self,
value: Option<String>,
) -> HyperliquidExecClientConfigBuilder<SetBaseUrlHttp<S>>where
S::BaseUrlHttp: IsUnset,
pub fn maybe_base_url_http(
self,
value: Option<String>,
) -> HyperliquidExecClientConfigBuilder<SetBaseUrlHttp<S>>where
S::BaseUrlHttp: IsUnset,
Sourcepub fn base_url_exchange(
self,
value: String,
) -> HyperliquidExecClientConfigBuilder<SetBaseUrlExchange<S>>where
S::BaseUrlExchange: IsUnset,
pub fn base_url_exchange(
self,
value: String,
) -> HyperliquidExecClientConfigBuilder<SetBaseUrlExchange<S>>where
S::BaseUrlExchange: IsUnset,
Sourcepub fn maybe_base_url_exchange(
self,
value: Option<String>,
) -> HyperliquidExecClientConfigBuilder<SetBaseUrlExchange<S>>where
S::BaseUrlExchange: IsUnset,
pub fn maybe_base_url_exchange(
self,
value: Option<String>,
) -> HyperliquidExecClientConfigBuilder<SetBaseUrlExchange<S>>where
S::BaseUrlExchange: IsUnset,
Sourcepub fn proxy_url(
self,
value: String,
) -> HyperliquidExecClientConfigBuilder<SetProxyUrl<S>>where
S::ProxyUrl: IsUnset,
pub fn proxy_url(
self,
value: String,
) -> HyperliquidExecClientConfigBuilder<SetProxyUrl<S>>where
S::ProxyUrl: IsUnset,
Sourcepub fn maybe_proxy_url(
self,
value: Option<String>,
) -> HyperliquidExecClientConfigBuilder<SetProxyUrl<S>>where
S::ProxyUrl: IsUnset,
pub fn maybe_proxy_url(
self,
value: Option<String>,
) -> HyperliquidExecClientConfigBuilder<SetProxyUrl<S>>where
S::ProxyUrl: IsUnset,
Sourcepub fn environment(
self,
value: HyperliquidEnvironment,
) -> HyperliquidExecClientConfigBuilder<SetEnvironment<S>>where
S::Environment: IsUnset,
pub fn environment(
self,
value: HyperliquidEnvironment,
) -> HyperliquidExecClientConfigBuilder<SetEnvironment<S>>where
S::Environment: IsUnset,
Sourcepub fn maybe_environment(
self,
value: Option<HyperliquidEnvironment>,
) -> HyperliquidExecClientConfigBuilder<SetEnvironment<S>>where
S::Environment: IsUnset,
pub fn maybe_environment(
self,
value: Option<HyperliquidEnvironment>,
) -> HyperliquidExecClientConfigBuilder<SetEnvironment<S>>where
S::Environment: IsUnset,
Sourcepub fn http_timeout_secs(
self,
value: u64,
) -> HyperliquidExecClientConfigBuilder<SetHttpTimeoutSecs<S>>where
S::HttpTimeoutSecs: IsUnset,
pub fn http_timeout_secs(
self,
value: u64,
) -> HyperliquidExecClientConfigBuilder<SetHttpTimeoutSecs<S>>where
S::HttpTimeoutSecs: IsUnset,
Sourcepub fn maybe_http_timeout_secs(
self,
value: Option<u64>,
) -> HyperliquidExecClientConfigBuilder<SetHttpTimeoutSecs<S>>where
S::HttpTimeoutSecs: IsUnset,
pub fn maybe_http_timeout_secs(
self,
value: Option<u64>,
) -> HyperliquidExecClientConfigBuilder<SetHttpTimeoutSecs<S>>where
S::HttpTimeoutSecs: IsUnset,
Sourcepub fn max_retries(
self,
value: u32,
) -> HyperliquidExecClientConfigBuilder<SetMaxRetries<S>>where
S::MaxRetries: IsUnset,
pub fn max_retries(
self,
value: u32,
) -> HyperliquidExecClientConfigBuilder<SetMaxRetries<S>>where
S::MaxRetries: IsUnset,
Sourcepub fn maybe_max_retries(
self,
value: Option<u32>,
) -> HyperliquidExecClientConfigBuilder<SetMaxRetries<S>>where
S::MaxRetries: IsUnset,
pub fn maybe_max_retries(
self,
value: Option<u32>,
) -> HyperliquidExecClientConfigBuilder<SetMaxRetries<S>>where
S::MaxRetries: IsUnset,
Sourcepub fn retry_delay_initial_ms(
self,
value: u64,
) -> HyperliquidExecClientConfigBuilder<SetRetryDelayInitialMs<S>>where
S::RetryDelayInitialMs: IsUnset,
pub fn retry_delay_initial_ms(
self,
value: u64,
) -> HyperliquidExecClientConfigBuilder<SetRetryDelayInitialMs<S>>where
S::RetryDelayInitialMs: IsUnset,
Sourcepub fn maybe_retry_delay_initial_ms(
self,
value: Option<u64>,
) -> HyperliquidExecClientConfigBuilder<SetRetryDelayInitialMs<S>>where
S::RetryDelayInitialMs: IsUnset,
pub fn maybe_retry_delay_initial_ms(
self,
value: Option<u64>,
) -> HyperliquidExecClientConfigBuilder<SetRetryDelayInitialMs<S>>where
S::RetryDelayInitialMs: IsUnset,
Sourcepub fn retry_delay_max_ms(
self,
value: u64,
) -> HyperliquidExecClientConfigBuilder<SetRetryDelayMaxMs<S>>where
S::RetryDelayMaxMs: IsUnset,
pub fn retry_delay_max_ms(
self,
value: u64,
) -> HyperliquidExecClientConfigBuilder<SetRetryDelayMaxMs<S>>where
S::RetryDelayMaxMs: IsUnset,
Sourcepub fn maybe_retry_delay_max_ms(
self,
value: Option<u64>,
) -> HyperliquidExecClientConfigBuilder<SetRetryDelayMaxMs<S>>where
S::RetryDelayMaxMs: IsUnset,
pub fn maybe_retry_delay_max_ms(
self,
value: Option<u64>,
) -> HyperliquidExecClientConfigBuilder<SetRetryDelayMaxMs<S>>where
S::RetryDelayMaxMs: IsUnset,
Sourcepub fn normalize_prices(
self,
value: bool,
) -> HyperliquidExecClientConfigBuilder<SetNormalizePrices<S>>where
S::NormalizePrices: IsUnset,
pub fn normalize_prices(
self,
value: bool,
) -> HyperliquidExecClientConfigBuilder<SetNormalizePrices<S>>where
S::NormalizePrices: IsUnset,
Sourcepub fn maybe_normalize_prices(
self,
value: Option<bool>,
) -> HyperliquidExecClientConfigBuilder<SetNormalizePrices<S>>where
S::NormalizePrices: IsUnset,
pub fn maybe_normalize_prices(
self,
value: Option<bool>,
) -> HyperliquidExecClientConfigBuilder<SetNormalizePrices<S>>where
S::NormalizePrices: IsUnset,
Sourcepub fn market_order_slippage_bps(
self,
value: u32,
) -> HyperliquidExecClientConfigBuilder<SetMarketOrderSlippageBps<S>>where
S::MarketOrderSlippageBps: IsUnset,
pub fn market_order_slippage_bps(
self,
value: u32,
) -> HyperliquidExecClientConfigBuilder<SetMarketOrderSlippageBps<S>>where
S::MarketOrderSlippageBps: IsUnset,
Sourcepub fn maybe_market_order_slippage_bps(
self,
value: Option<u32>,
) -> HyperliquidExecClientConfigBuilder<SetMarketOrderSlippageBps<S>>where
S::MarketOrderSlippageBps: IsUnset,
pub fn maybe_market_order_slippage_bps(
self,
value: Option<u32>,
) -> HyperliquidExecClientConfigBuilder<SetMarketOrderSlippageBps<S>>where
S::MarketOrderSlippageBps: IsUnset,
Sourcepub fn transport_backend(
self,
value: TransportBackend,
) -> HyperliquidExecClientConfigBuilder<SetTransportBackend<S>>where
S::TransportBackend: IsUnset,
pub fn transport_backend(
self,
value: TransportBackend,
) -> HyperliquidExecClientConfigBuilder<SetTransportBackend<S>>where
S::TransportBackend: IsUnset,
Sourcepub fn maybe_transport_backend(
self,
value: Option<TransportBackend>,
) -> HyperliquidExecClientConfigBuilder<SetTransportBackend<S>>where
S::TransportBackend: IsUnset,
pub fn maybe_transport_backend(
self,
value: Option<TransportBackend>,
) -> HyperliquidExecClientConfigBuilder<SetTransportBackend<S>>where
S::TransportBackend: IsUnset,
Sourcepub fn ws_post_timeout_secs(
self,
value: u64,
) -> HyperliquidExecClientConfigBuilder<SetWsPostTimeoutSecs<S>>where
S::WsPostTimeoutSecs: IsUnset,
pub fn ws_post_timeout_secs(
self,
value: u64,
) -> HyperliquidExecClientConfigBuilder<SetWsPostTimeoutSecs<S>>where
S::WsPostTimeoutSecs: IsUnset,
Sourcepub fn maybe_ws_post_timeout_secs(
self,
value: Option<u64>,
) -> HyperliquidExecClientConfigBuilder<SetWsPostTimeoutSecs<S>>where
S::WsPostTimeoutSecs: IsUnset,
pub fn maybe_ws_post_timeout_secs(
self,
value: Option<u64>,
) -> HyperliquidExecClientConfigBuilder<SetWsPostTimeoutSecs<S>>where
S::WsPostTimeoutSecs: IsUnset,
Sourcepub fn outcome_settlement_poll_secs(
self,
value: u64,
) -> HyperliquidExecClientConfigBuilder<SetOutcomeSettlementPollSecs<S>>where
S::OutcomeSettlementPollSecs: IsUnset,
pub fn outcome_settlement_poll_secs(
self,
value: u64,
) -> HyperliquidExecClientConfigBuilder<SetOutcomeSettlementPollSecs<S>>where
S::OutcomeSettlementPollSecs: IsUnset,
Sourcepub fn maybe_outcome_settlement_poll_secs(
self,
value: Option<u64>,
) -> HyperliquidExecClientConfigBuilder<SetOutcomeSettlementPollSecs<S>>where
S::OutcomeSettlementPollSecs: IsUnset,
pub fn maybe_outcome_settlement_poll_secs(
self,
value: Option<u64>,
) -> HyperliquidExecClientConfigBuilder<SetOutcomeSettlementPollSecs<S>>where
S::OutcomeSettlementPollSecs: IsUnset,