HyperliquidExecClientConfigBuilder

Struct HyperliquidExecClientConfigBuilder 

pub struct HyperliquidExecClientConfigBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> HyperliquidExecClientConfigBuilder<S>

pub fn build(self) -> HyperliquidExecClientConfig
where S: IsComplete,

Finish building and return the requested object

pub fn private_key( self, value: String, ) -> HyperliquidExecClientConfigBuilder<SetPrivateKey<S>>
where S::PrivateKey: IsUnset,

Optional (Some / Option setters). Private key for signing transactions.

If not provided, falls back to environment variable:

  • Mainnet: HYPERLIQUID_PK
  • Testnet: HYPERLIQUID_TESTNET_PK
pub fn maybe_private_key( self, value: Option<String>, ) -> HyperliquidExecClientConfigBuilder<SetPrivateKey<S>>
where S::PrivateKey: IsUnset,

Optional (Some / Option setters). Private key for signing transactions.

If not provided, falls back to environment variable:

  • Mainnet: HYPERLIQUID_PK
  • Testnet: HYPERLIQUID_TESTNET_PK
pub fn vault_address( self, value: String, ) -> HyperliquidExecClientConfigBuilder<SetVaultAddress<S>>
where S::VaultAddress: IsUnset,

Optional (Some / Option setters). Optional vault address for vault operations.

pub fn maybe_vault_address( self, value: Option<String>, ) -> HyperliquidExecClientConfigBuilder<SetVaultAddress<S>>
where S::VaultAddress: IsUnset,

Optional (Some / Option setters). Optional vault address for vault operations.

pub fn account_address( self, value: String, ) -> HyperliquidExecClientConfigBuilder<SetAccountAddress<S>>
where S::AccountAddress: IsUnset,

Optional (Some / Option setters). Optional main account address when using an agent wallet (API sub-key). When set, used for balance queries, position reports, and WS subscriptions instead of the address derived from the private key.

pub fn maybe_account_address( self, value: Option<String>, ) -> HyperliquidExecClientConfigBuilder<SetAccountAddress<S>>
where S::AccountAddress: IsUnset,

Optional (Some / Option setters). Optional main account address when using an agent wallet (API sub-key). When set, used for balance queries, position reports, and WS subscriptions instead of the address derived from the private key.

pub fn base_url_ws( self, value: String, ) -> HyperliquidExecClientConfigBuilder<SetBaseUrlWs<S>>
where S::BaseUrlWs: IsUnset,

Optional (Some / Option setters). Override for the WebSocket URL.

pub fn maybe_base_url_ws( self, value: Option<String>, ) -> HyperliquidExecClientConfigBuilder<SetBaseUrlWs<S>>
where S::BaseUrlWs: IsUnset,

Optional (Some / Option setters). Override for the WebSocket URL.

pub fn base_url_http( self, value: String, ) -> HyperliquidExecClientConfigBuilder<SetBaseUrlHttp<S>>
where S::BaseUrlHttp: IsUnset,

Optional (Some / Option setters). Override for the HTTP info URL.

pub fn maybe_base_url_http( self, value: Option<String>, ) -> HyperliquidExecClientConfigBuilder<SetBaseUrlHttp<S>>
where S::BaseUrlHttp: IsUnset,

Optional (Some / Option setters). Override for the HTTP info URL.

pub fn base_url_exchange( self, value: String, ) -> HyperliquidExecClientConfigBuilder<SetBaseUrlExchange<S>>
where S::BaseUrlExchange: IsUnset,

Optional (Some / Option setters). Override for the exchange API URL.

pub fn maybe_base_url_exchange( self, value: Option<String>, ) -> HyperliquidExecClientConfigBuilder<SetBaseUrlExchange<S>>
where S::BaseUrlExchange: IsUnset,

Optional (Some / Option setters). Override for the exchange API URL.

pub fn http_proxy_url( self, value: String, ) -> HyperliquidExecClientConfigBuilder<SetHttpProxyUrl<S>>
where S::HttpProxyUrl: IsUnset,

Optional (Some / Option setters). Optional HTTP proxy URL.

pub fn maybe_http_proxy_url( self, value: Option<String>, ) -> HyperliquidExecClientConfigBuilder<SetHttpProxyUrl<S>>
where S::HttpProxyUrl: IsUnset,

Optional (Some / Option setters). Optional HTTP proxy URL.

pub fn ws_proxy_url( self, value: String, ) -> HyperliquidExecClientConfigBuilder<SetWsProxyUrl<S>>
where S::WsProxyUrl: IsUnset,

Optional (Some / Option setters). Optional WebSocket proxy URL.

Note: WebSocket proxy support is not yet implemented. This field is reserved for future functionality. Use http_proxy_url for REST API proxy support.

pub fn maybe_ws_proxy_url( self, value: Option<String>, ) -> HyperliquidExecClientConfigBuilder<SetWsProxyUrl<S>>
where S::WsProxyUrl: IsUnset,

Optional (Some / Option setters). Optional WebSocket proxy URL.

Note: WebSocket proxy support is not yet implemented. This field is reserved for future functionality. Use http_proxy_url for REST API proxy support.

pub fn is_testnet( self, value: bool, ) -> HyperliquidExecClientConfigBuilder<SetIsTestnet<S>>
where S::IsTestnet: IsUnset,

Optional (Some / Option setters). Default: false.

When true the client will use Hyperliquid testnet endpoints.

pub fn maybe_is_testnet( self, value: Option<bool>, ) -> HyperliquidExecClientConfigBuilder<SetIsTestnet<S>>
where S::IsTestnet: IsUnset,

Optional (Some / Option setters). Default: false.

When true the client will use Hyperliquid testnet endpoints.

pub fn http_timeout_secs( self, value: u64, ) -> HyperliquidExecClientConfigBuilder<SetHttpTimeoutSecs<S>>
where S::HttpTimeoutSecs: IsUnset,

Optional (Some / Option setters). Default: 60.

HTTP timeout in seconds.

pub fn maybe_http_timeout_secs( self, value: Option<u64>, ) -> HyperliquidExecClientConfigBuilder<SetHttpTimeoutSecs<S>>
where S::HttpTimeoutSecs: IsUnset,

Optional (Some / Option setters). Default: 60.

HTTP timeout in seconds.

pub fn max_retries( self, value: u32, ) -> HyperliquidExecClientConfigBuilder<SetMaxRetries<S>>
where S::MaxRetries: IsUnset,

Optional (Some / Option setters). Default: 3.

Maximum number of retry attempts for HTTP requests.

pub fn maybe_max_retries( self, value: Option<u32>, ) -> HyperliquidExecClientConfigBuilder<SetMaxRetries<S>>
where S::MaxRetries: IsUnset,

Optional (Some / Option setters). Default: 3.

Maximum number of retry attempts for HTTP requests.

pub fn retry_delay_initial_ms( self, value: u64, ) -> HyperliquidExecClientConfigBuilder<SetRetryDelayInitialMs<S>>
where S::RetryDelayInitialMs: IsUnset,

Optional (Some / Option setters). Default: 100.

Initial retry delay in milliseconds.

pub fn maybe_retry_delay_initial_ms( self, value: Option<u64>, ) -> HyperliquidExecClientConfigBuilder<SetRetryDelayInitialMs<S>>
where S::RetryDelayInitialMs: IsUnset,

Optional (Some / Option setters). Default: 100.

Initial retry delay in milliseconds.

pub fn retry_delay_max_ms( self, value: u64, ) -> HyperliquidExecClientConfigBuilder<SetRetryDelayMaxMs<S>>
where S::RetryDelayMaxMs: IsUnset,

Optional (Some / Option setters). Default: 5000.

Maximum retry delay in milliseconds.

pub fn maybe_retry_delay_max_ms( self, value: Option<u64>, ) -> HyperliquidExecClientConfigBuilder<SetRetryDelayMaxMs<S>>
where S::RetryDelayMaxMs: IsUnset,

Optional (Some / Option setters). Default: 5000.

Maximum retry delay in milliseconds.

pub fn normalize_prices( self, value: bool, ) -> HyperliquidExecClientConfigBuilder<SetNormalizePrices<S>>
where S::NormalizePrices: IsUnset,

Optional (Some / Option setters). Default: true.

When true, normalize order prices to 5 significant figures before submission (Hyperliquid requirement).

pub fn maybe_normalize_prices( self, value: Option<bool>, ) -> HyperliquidExecClientConfigBuilder<SetNormalizePrices<S>>
where S::NormalizePrices: IsUnset,

Optional (Some / Option setters). Default: true.

When true, normalize order prices to 5 significant figures before submission (Hyperliquid requirement).